<?php
/**
 * Basque language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Xabi Ezpeleta <xezpeleta@mendikute.com>
 * @author Inko Illarramendi <inko.i.a@gmail.com>
 * @author Zigor Astarbe <astarbe@gmail.com>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '“';
$lang['doublequoteclosing']    = '”';
$lang['singlequoteopening']    = '‘';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '’';
$lang['btn_edit']              = 'Aldatu orri hau';
$lang['btn_source']            = 'Kodea ikusi';
$lang['btn_show']              = 'Orria ikusi';
$lang['btn_create']            = 'Sortu orri hau';
$lang['btn_search']            = 'Bilatu';
$lang['btn_save']              = 'Gorde';
$lang['btn_preview']           = 'Aurrebista';
$lang['btn_top']               = 'Itzuli gora';
$lang['btn_newer']             = '<< berriagoa';
$lang['btn_older']             = 'zaharragoa >>';
$lang['btn_revs']              = 'Berrikuspen zaharrak';
$lang['btn_recent']            = 'Azken aldaketak';
$lang['btn_upload']            = 'Ireki';
$lang['btn_cancel']            = 'Ezeztatu';
$lang['btn_index']             = 'Aurkibidea';
$lang['btn_secedit']           = 'Aldatu';
$lang['btn_login']             = 'Sartu';
$lang['btn_logout']            = 'Irten';
$lang['btn_admin']             = 'Admin';
$lang['btn_update']            = 'Eguneratu';
$lang['btn_delete']            = 'Ezabatu';
$lang['btn_back']              = 'Atzera';
$lang['btn_backlink']          = 'Itzulera estekak';
$lang['btn_backtomedia']       = 'Atzera Multimedia Fitxategiaren Aukeraketara';
$lang['btn_subscribe']         = 'Harpidetu Orri Aldaketetara';
$lang['btn_profile']           = 'Eguneratu Profila ';
$lang['btn_reset']             = 'Aldaketak Desegin';
$lang['btn_resendpwd']         = 'Pasahitza berria ezarri';
$lang['btn_draft']             = 'Editatu zirriborroa';
$lang['btn_recover']           = 'Berreskuratu zirriborroa';
$lang['btn_draftdel']          = 'Ezabatu zirriborroa';
$lang['btn_revert']            = 'Berrezarri';
$lang['btn_register']          = 'Erregistratu';
$lang['btn_apply']             = 'Baieztatu';
$lang['btn_media']             = 'Media Kudeatzailea';
$lang['loggedinas']            = 'Erabiltzailea';
$lang['user']                  = 'Erabiltzailea';
$lang['pass']                  = 'Pasahitza';
$lang['newpass']               = 'Pasahitz berria';
$lang['oldpass']               = 'Baieztatu oraingo pasahitza';
$lang['passchk']               = 'berriz';
$lang['remember']              = 'Gogoratu';
$lang['fullname']              = 'Izen Deiturak';
$lang['email']                 = 'E-Maila';
$lang['profile']               = 'Erabiltzaile Profila';
$lang['badlogin']              = 'Barkatu, prozesuak huts egin du; saiatu berriz';
$lang['minoredit']             = 'Aldaketa Txikiak';
$lang['draftdate']             = 'Zirriborroa automatikoki gorde da hemen:';
$lang['nosecedit']             = 'Orria aldatua izan da bitartean, info atala zaharkituta geratu da, orri osoa kargatu da horren ordez.';
$lang['regmissing']            = 'Barkatu, hutsune guztiak bete behar dituzu.';
$lang['reguexists']            = 'Barkatu, izen bereko erabiltzailea existitzen da.';
$lang['regsuccess']            = 'Erabiltzailea sortu da. Pasahitza mailez bidaliko zaizu.';
$lang['regsuccess2']           = 'Erabiltzailea sortua izan da.';
$lang['regmailfail']           = 'Badirudi arazoren bat egon dela pasahitza mailez bidaltzeko orduan. Administratzailearekin harremanetan jarri!';
$lang['regbadmail']            = 'Emandako helbidea ez da zuzena - jarri harremanetan administratzailearekin hau akats bat dela uste baduzu';
$lang['regbadpass']            = 'Idatzitako bi pasahitzak ez dira berdinak, berriz saiatu.';
$lang['regpwmail']             = 'Zure DokuWiki pasahitza';
$lang['reghere']               = 'Oraindik ez duzu konturik? Eginzazu bat!';
$lang['profna']                = 'Wiki honek ez du profilaren aldaketa ahalbidetzen';
$lang['profnochange']          = 'Aldaketarik ez, ez dago egiteko ezer.';
$lang['profnoempty']           = 'Izen edota e-posta hutsa ez dago onartua.';
$lang['profchanged']           = 'Erabiltzaile profila arrakastaz eguneratua.';
$lang['pwdforget']             = 'Pasahitza ahaztu duzu? Eskuratu berri bat';
$lang['resendna']              = 'Wiki honek ez du pasahitz berbidalketa onartzen.';
$lang['resendpwd']             = '-entzat pasahitza berria ezarri';
$lang['resendpwdmissing']      = 'Barkatu, eremu guztiak bete behar dituzu.';
$lang['resendpwdnouser']       = 'Barkatu, ez dugu erabiltzaile hori datu-basean aurkitzen';
$lang['resendpwdbadauth']      = 'Barkatu, kautotze kodea ez da baliozkoa. Ziurtatu baieztapen esteka osoa erabili duzula.';
$lang['resendpwdconfirm']      = 'Baieztapen esteka bat e-postaz bidali da.';
$lang['resendpwdsuccess']      = 'Zure pasahitz berria e-postaz bidali da.';
$lang['license']               = 'Besterik esan ezean, wiki hontako edukia ondorengo lizentziapean argitaratzen da:';
$lang['licenseok']             = 'Oharra: Orri hau editatzean, zure edukia ondorengo lizentziapean argitaratzea onartzen duzu: ';
$lang['searchmedia']           = 'Bilatu fitxategi izena:';
$lang['searchmedia_in']        = 'Bilatu %s-n';
$lang['txt_upload']            = 'Ireki nahi den fitxategia aukeratu';
$lang['txt_filename']          = 'Idatzi wikiname-a (aukerazkoa)';
$lang['txt_overwrt']           = 'Oraingo fitxategiaren gainean idatzi';
$lang['lockedby']              = 'Momentu honetan blokeatzen:';
$lang['lockexpire']            = 'Blokeaketa iraungitzen da:';
$lang['js']['willexpire']      = 'Zure blokeaketa orri hau aldatzeko minutu batean iraungitzen da.\nGatazkak saihesteko, aurreikusi botoia erabili blokeaketa denboragailua berrabiarazteko.';
$lang['js']['notsavedyet']     = 'Gorde gabeko aldaketak galdu egingo dira.
Benetan jarraitu nahi duzu?';
$lang['js']['searchmedia']     = 'Bilatu fitxategiak';
$lang['js']['keepopen']        = 'Mantendu leihoa irekita aukeraketan';
$lang['js']['hidedetails']     = 'Xehetasunak Ezkutatu';
$lang['js']['mediatitle']      = 'Esteken ezarpenak';
$lang['js']['mediadisplay']    = 'Esteka mota';
$lang['js']['mediaalign']      = 'Lerrokatzea';
$lang['js']['mediasize']       = 'Irudi tamaina';
$lang['js']['mediatarget']     = 'Estekaren helburua';
$lang['js']['mediaclose']      = 'Itxi';
$lang['js']['mediainsert']     = 'Txertatu';
$lang['js']['mediadisplayimg'] = 'Irudia erakutsi';
$lang['js']['mediadisplaylnk'] = 'Esteka bakarrik erakutsi';
$lang['js']['mediasmall']      = 'Bertsio txikia';
$lang['js']['mediamedium']     = 'Bertsio ertaina';
$lang['js']['medialarge']      = 'Bertsio handia';
$lang['js']['mediaoriginal']   = 'Jatorrizko bertsioa';
$lang['js']['medialnk']        = 'Esteka xehetasunen orrira';
$lang['js']['mediadirect']     = 'Jatorrizkora esteka zuzena';
$lang['js']['medianolnk']      = 'Estekarik ez';
$lang['js']['medianolink']     = 'Ez estekatu irudia';
$lang['js']['medialeft']       = 'Irudia ezkerrean lerrokatu';
$lang['js']['mediaright']      = 'Irudia eskuinean lerrokatu';
$lang['js']['mediacenter']     = 'Irudia erdian lerrokatu';
$lang['js']['medianoalign']    = 'Ez erabili lerrokatzerik';
$lang['js']['nosmblinks']      = 'Window baliabide konpartituetara estekek Microsoft Internet Explorer-en bakarrik balio dute.
Esteka kopiatu eta itsatsi dezakezu dena den.';
$lang['js']['linkwiz']         = 'Estekatze Laguntzailea';
$lang['js']['linkto']          = 'Estekatu hona:';
$lang['js']['del_confirm']     = 'Benetan ezabatu aukeratutako fitxategia(k)?';
$lang['js']['restore_confirm'] = 'Benetan bertsio hau berrezarri?';
$lang['js']['media_diff']      = 'Diferentziak ikusi:';
$lang['js']['media_diff_both'] = 'Ondoz ondo';
$lang['js']['media_select']    = 'Fitxategiak hautatu';
$lang['js']['media_upload_btn'] = 'Igo';
$lang['js']['media_done_btn']  = 'Egina';
$lang['js']['media_drop']      = 'Fitxategiak igotzeko hona bota';
$lang['js']['media_cancel']    = 'ezabatu';
$lang['js']['media_overwrt']   = 'Dauden fitxategiak berridatzi';
$lang['rssfailed']             = 'Errorea gertatu da feed hau irakurtzean:';
$lang['nothingfound']          = 'Ez da ezer aurkitu.';
$lang['mediaselect']           = 'Aukeratu Multimedia fitxategia';
$lang['fileupload']            = 'Igo Multimedia Fitxategia';
$lang['uploadsucc']            = 'Igoera arrakastatsua';
$lang['uploadfail']            = 'Igoerak huts egin du. Baimen arazoengatik agian?';
$lang['uploadwrong']           = 'Fitxategi igoera ukatua. Fitxategi-luzapen hau debekatua dago!';
$lang['uploadexist']           = 'Fitxategia lehenagotik existitzen da. Ez da ezer egin.';
$lang['uploadbadcontent']      = 'Igotako edukia ez dator bat %s fitxategi-luzapenarekin.';
$lang['uploadspam']            = 'Igoera spam zerrenda beltzak blokeatu du.';
$lang['uploadxss']             = 'Igoera blokeatua izan da eduki maltzurra edukitzeko susmoagatik.';
$lang['uploadsize']            = 'Igotako fitxategia handiegia zen. (max. %s)';
$lang['deletesucc']            = 'Ezabatua izan da "%s" fitxategia.';
$lang['deletefail']            = 'Ezin izan da "%s" ezabatu - egiaztatu baimenak.';
$lang['mediainuse']            = 'Ez da "%s" fitxategia ezabatu - oraindik erabilia izaten ari da.';
$lang['namespaces']            = 'Izen-espazioak';
$lang['mediafiles']            = 'Fitxategiak eskuragarri hemen:';
$lang['accessdenied']          = 'Ez zaude orri hau ikusteko baimendua';
$lang['mediausage']            = 'Erabili ondoko sintaxia fitxategi honi erreferentzia egiteko:';
$lang['mediaview']             = 'Ikusi jatorrizko fitxategia';
$lang['mediaroot']             = 'root';
$lang['mediaupload']           = 'Igo fitxategi bat uneko izen-espaziora. Azpi-izen-espazioak sortzeko, zure "Honela igo" fitxategi izenaren aurretik ezarri, bi puntuz (:) bananduta.';
$lang['mediaextchange']        = 'Fitxategi-luzapena aldatua .%s -tik .%s! -ra';
$lang['reference']             = 'Erreferentziak honentzat:';
$lang['ref_inuse']             = 'Fitxategia ezin da ezabatu, honako orri hauek erabiltzen dutelako:';
$lang['ref_hidden']            = 'Erreferentzi batzuk irakurtzeko baimenik ez duzun orrietan daude';
$lang['hits']                  = 'Hits';
$lang['quickhits']             = 'Matching pagenames';
$lang['toc']                   = 'Eduki Taula';
$lang['current']               = 'egungoa';
$lang['yours']                 = 'Zure Bertsioa';
$lang['diff']                  = 'egungo bertsioarekin dituen aldaketak aurkezten ditu';
$lang['diff2']                 = 'Erakutsi desberdintasunak aukeratutako bertsioen artean';
$lang['difflink']              = 'Estekatu konparaketa bista honetara';
$lang['diff_type']             = 'Ikusi diferentziak:';
$lang['diff_inline']           = 'Lerro tartean';
$lang['diff_side']             = 'Ondoz ondo';
$lang['line']                  = 'Marra';
$lang['breadcrumb']            = 'Traza';
$lang['youarehere']            = 'Hemen zaude';
$lang['lastmod']               = 'Azken aldaketa';
$lang['by']                    = 'egilea:';
$lang['deleted']               = 'ezabatua';
$lang['created']               = 'sortua';
$lang['restored']              = 'bertsio zaharra berrezarria';
$lang['external_edit']         = 'kanpoko aldaketa';
$lang['summary']               = 'Aldatu laburpena';
$lang['noflash']               = '<a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> beharrezkoa da eduki hau bistaratzeko.';
$lang['download']              = 'Deskarga Snippet-a';
$lang['tools']                 = 'Tresnak';
$lang['user_tools']            = 'Erabiltzaile Tresnak';
$lang['site_tools']            = 'Gune Tresnak';
$lang['page_tools']            = 'Orri Tresnak';
$lang['skip_to_content']       = 'edukira sahiestu';
$lang['sidebar']               = 'Alboko-barra';
$lang['mail_newpage']          = '[DokuWiki] gehitutako orria:';
$lang['mail_changed']          = '[DokuWiki] aldatutako orria:';
$lang['mail_subscribe_list']   = 'izen-espazioan aldatutako orriak:';
$lang['mail_new_user']         = 'erabiltzaile berria:';
$lang['mail_upload']           = 'fitxategia igota:';
$lang['changes_type']          = '-ren aldaketak ikusi';
$lang['pages_changes']         = 'Orriak';
$lang['media_changes']         = 'Media fitxategiak';
$lang['both_changes']          = 'Bai orriak nahiz media fitxategiak';
$lang['qb_bold']               = 'Letra beltzez';
$lang['qb_italic']             = 'Letra italiarrez';
$lang['qb_underl']             = 'Azpimarratua';
$lang['qb_code']               = 'Kodea';
$lang['qb_strike']             = 'Marratu Testua';
$lang['qb_h1']                 = 'Izenburua 1';
$lang['qb_h2']                 = 'Izenburua 2';
$lang['qb_h3']                 = 'Izenburua 3';
$lang['qb_h4']                 = 'Izenburua 4';
$lang['qb_h5']                 = 'Izenburua 5';
$lang['qb_h']                  = 'Izenburua';
$lang['qb_hs']                 = 'Izenburua Aukeratu';
$lang['qb_hplus']              = 'Izenburu Handiagoa';
$lang['qb_hminus']             = 'Izenburu Txikiagoa';
$lang['qb_hequal']             = 'Maila Berdineko Izenburua';
$lang['qb_link']               = 'Barruko Lotura';
$lang['qb_extlink']            = 'Kanpoko Lotura';
$lang['qb_hr']                 = 'Horizontal Marra';
$lang['qb_ol']                 = 'Zerrenda ordenatuko gaia';
$lang['qb_ul']                 = 'Zerrenda desordenatuko gaia';
$lang['qb_media']              = 'Irudiak eta beste fitxategiak gehitu';
$lang['qb_sig']                = 'Gehitu sinadura';
$lang['qb_smileys']            = 'Irrifartxoak';
$lang['qb_chars']              = 'Karaktere Bereziak';
$lang['upperns']               = 'Jauzi izen-espazio gurasora';
$lang['admin_register']        = 'Erabiltzaile berria gehitu';
$lang['metaedit']              = 'Metadatua Aldatu';
$lang['metasaveerr']           = 'Metadatuaren idazketak huts egin du';
$lang['metasaveok']            = 'Metadatua gordea';
$lang['img_backto']            = 'Atzera hona';
$lang['img_title']             = 'Izenburua';
$lang['img_caption']           = 'Epigrafea';
$lang['img_date']              = 'Data';
$lang['img_fname']             = 'Fitxategi izena';
$lang['img_fsize']             = 'Tamaina';
$lang['img_artist']            = 'Artista';
$lang['img_copyr']             = 'Copyright';
$lang['img_format']            = 'Formatua';
$lang['img_camera']            = 'Kamera';
$lang['img_keywords']          = 'Hitz-gakoak';
$lang['img_width']             = 'Zabalera';
$lang['img_height']            = 'Altuera';
$lang['img_manager']           = 'Media kudeatzailean ikusi';
$lang['subscr_subscribe_success'] = '%s gehitua %s-ren harpidetza zerrendara';
$lang['subscr_subscribe_error'] = 'Errorea %s gehitzen %s-ren harpidetza zerrendara';
$lang['subscr_subscribe_noaddress'] = 'Ez dago helbiderik zure login-arekin lotuta, ezin zara harpidetza zerrendara gehitua izan.';
$lang['subscr_unsubscribe_success'] = '%s ezabatua %s-ren harpidetza zerrendatik';
$lang['subscr_unsubscribe_error'] = 'Errorea %s ezabatzen %s-ren harpidetza zerrendatik';
$lang['subscr_already_subscribed'] = '%s lehendik harpidetua dago %s-n';
$lang['subscr_not_subscribed'] = '%s ez dago %s-n harpidetua';
$lang['subscr_m_not_subscribed'] = 'Momentu honetan ez zaude orri honetara edo izen-espazio honetara harpidetua.';
$lang['subscr_m_new_header']   = 'Gehitu harpidetza';
$lang['subscr_m_current_header'] = 'Uneko harpidetzak';
$lang['subscr_m_unsubscribe']  = 'Kendu harpidetza';
$lang['subscr_m_subscribe']    = 'Harpidetu';
$lang['subscr_m_receive']      = 'Jaso';
$lang['subscr_style_every']    = 'e-posta aldaketa bakoitzean';
$lang['subscr_style_digest']   = 'e-posta laburbildua orri bakoitzeko aldaketentzat (%.2f egunero)';
$lang['subscr_style_list']     = 'aldatutako orrien zerrenda azken e-postatik (%.2f egunero)';
$lang['authmodfailed']         = 'Erabiltzaile kautotzearen konfigurazioa okerra da. Mesedez, eman honen berri Wiki administratzaileari';
$lang['authtempfail']          = 'Erabiltzaile kautotzea denboraldi batez ez dago erabilgarri. Egoerak hala jarraitzen badu, mesedez, eman honen berri Wiki administratzaileari';
$lang['authpwdexpire']         = 'Zure pasahitza %d egun barru iraungiko da, laster aldatu beharko zenuke.';
$lang['i_chooselang']          = 'Hautatu zure hizkuntza';
$lang['i_installer']           = 'DokuWiki instalatzailea';
$lang['i_wikiname']            = 'Wiki Izena';
$lang['i_enableacl']           = 'Gaitu ACL (gomendatua) (ACL: Atzipen Kontrol Lista)';
$lang['i_superuser']           = 'Supererabiltzailea';
$lang['i_problems']            = 'Instalatzaileak arazo batzuk aurkitu ditu, behean azalduak. Ezin duzu horiek konpondu arte jarraitu.';
$lang['i_modified']            = 'Segurtasun arrazoiengatik, script hau DokuWikiren instalazio berri eta aldatu gabeko batekin bakarrik dabil. Deskargatutako paketetik fitxategiak berriz atera edo <a href="http://dokuwiki.org/install">DokuWikiren instalazio azalpenak</a> osorik irakurri beharko zenituzke.';
$lang['i_funcna']              = 'PHP <code>%s</code> funtzioa ez dago erabilgarri. Agian zure hosting hornitzaileak arrazoiren batengatik ezgaituko zuen?';
$lang['i_phpver']              = 'Zure PHP <code>%s</code> bertsioa behar den <code>%s</code> bertsioa baino zaharragoa da. PHP instalazioa eguneratu beharra daukazu.';
$lang['i_permfail']            = 'DokuWiki ez da   <code>%s</code> idazteko gai. Direktorio honen baimenen konfigurazioa konpondu behar duzu!';
$lang['i_confexists']          = '<code>%s</code> lehendik existitzen da';
$lang['i_writeerr']            = 'Ezin da <code>%s</code> sortu. Direktorioaren/fitxategiaren baimenak egiaztatu eta sortu fitxategia eskuz.';
$lang['i_badhash']             = 'aldatutakoa edo ezezaguna den dokuwiki.php (hash=<code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> - balioa arauen aurka edo hutsa';
$lang['i_success']             = 'Konfigurazioa arrakastaz amaitu da. Orain, install.php fitxategia ezabatu dezakezu. Jarraitu ezazu <a href="doku.php">zure DokuWiki berrian</a>.';
$lang['i_failure']             = 'Akats batzuk gertatu dira konfigurazio fitxategiak idazterakoan. Hauek eskuz konpondu beharra izan dezakezu <a href="doku.php">zure DokuWiki berria</a> erabili ahal izan aurretik.';
$lang['i_policy']              = 'Hasierako ACL politika';
$lang['i_pol0']                = 'Wiki Irekia (irakurri, idatzi, fitxategiak igo edonorentzat)';
$lang['i_pol1']                = 'Wiki Publikoa (irakurri edonorentzat, idatzi eta fitxategiak igo erregistratutako erabiltzaileentzat)';
$lang['i_pol2']                = 'Wiki Itxia (irakurri, idatzi, fitxategiak igo erregistratutako erabiltzaileentzat soilik)';
$lang['i_retry']               = 'Berriz saiatu';
$lang['i_license']             = 'Mesedez, aukeratu zein lizentzipean ezarri nahi duzun zure edukia:';
$lang['recent_global']         = 'Une honetan <b>%s</b> izen-espazioaren barneko aldaketak ikusten ari zara.<a href="%s"> Wiki osoaren azken aldaketak</a> ere ikusi ditzakezu.';
$lang['years']                 = 'duela %d urte';
$lang['months']                = 'duela %d hilabete';
$lang['weeks']                 = 'duela %d aste';
$lang['days']                  = 'duela %d egun';
$lang['hours']                 = 'duela %d ordu';
$lang['minutes']               = 'duela %d minutu';
$lang['seconds']               = 'duela %d segundu';
$lang['wordblock']             = 'Zure aldaketa ez da aldatua izan blokeatutako testua (spam) daukalako.';
$lang['media_uploadtab']       = 'Igo';
$lang['media_searchtab']       = 'Bilatu';
$lang['media_file']            = 'Fitxategia';
$lang['media_viewtab']         = 'Begiratu';
$lang['media_edittab']         = 'Editatu';
$lang['media_historytab']      = 'Historia';
$lang['media_sort_name']       = 'Izena';
$lang['media_sort_date']       = 'Data';
$lang['media_files']           = '%s -n fitxategiak';
$lang['media_upload']          = 'Igo %s -ra';
$lang['media_search']          = 'Bilatu %s -n';
$lang['media_view']            = '%s';
$lang['media_viewold']         = '%s -n %s';
$lang['media_edit']            = '%s editatu';
$lang['media_update']          = 'Bertsio berria igo';
$lang['media_restore']         = 'Bertsio hau berrezarri';
